
def_load_antennalist = """
def drivecasa_load_antennalist(antennalist_path):
    with open(antennalist_path, 'r') as f:
        x = [];
        y = [];
        z = [];
        d = []
        lines = f.readlines()
        for l in lines:
            items = l.split()
            if (items[0] != '#'):
                x.append(float(items[0]))
                y.append(float(items[1]))
                z.append(float(items[2]))
                d.append(float(items[3]))
    return x, y, z, d
    """


import os

_test_data_dir = os.path.dirname(__file__)


# _ami_uvfits_basename = 'SWIFT_541371-121212.fits'

_ami_uvfits_basenames = ['SWIFT_544784-130104.fits', 'SWIFT_544784-130106.fits']

_ami_vis_basenames = ['SWIFT_544784-130104.ms', 'SWIFT_544784-130106.ms']

_ami_cleaned_img_basename = 'SWIFT_544784-130104.clean.image'

ami_uvfits_paths = [os.path.abspath(os.path.join(_test_data_dir, bname))
                    for bname in _ami_uvfits_basenames]

ami_vis_paths = [os.path.abspath(os.path.join(_test_data_dir, bname))
                    for bname in _ami_vis_basenames]

ami_cleaned_img = os.path.abspath(os.path.join(_test_data_dir,
                                               _ami_cleaned_img_basename))




import unittest
from unittest import TestCase
import drivecasa
import os
import subprocess
import StringIO
import warnings
import shutil

from drivecasa import commands
from .. import sample_data as test_data


class TestConcat(TestCase):
    def shortDescription(self):
        return None

    @classmethod
    def setUpClass(cls):
        cls.casa = drivecasa.Casapy(echo_to_stdout=False)

    def setUp(self):
        self.output_dir = os.path.join(drivecasa.default_test_ouput_dir,
                                       'concat_output')
        self.testvis_list = test_data.ami_vis_paths
        # Ensure that the output dir will be created if not already present
        # (Also deletes the output ms if present)
        if os.path.isdir(self.output_dir):
            shutil.rmtree(self.output_dir)

    def test_default(self):
        script = []
        expected_ms = commands.concat(
                                    script,
                                    self.testvis_list,
                                    out_dir=self.output_dir)
        # Manually ensure target does not pre-exist
        if os.path.isdir(expected_ms):
             shutil.rmtree(expected_ms)
        # Test in usual case, not-preexisting
        casa_out, errs = self.casa.run_script(script)
        self.assertTrue(os.path.isdir(expected_ms))

    def test_unicode(self):
        script = []
        unicode_list = [unicode(v) for v in self.testvis_list]
        expected_ms = commands.concat(
                                    script,
                                    unicode_list,
                                    out_dir=self.output_dir)
        print expected_ms
        # Manually ensure target does not pre-exist
        if os.path.isdir(expected_ms):
             shutil.rmtree(expected_ms)
        # Test in usual case, not-preexisting
        casa_out, errs = self.casa.run_script(script)
        print '\n'.join(casa_out)
        self.assertTrue(os.path.isdir(expected_ms))



import unittest
from unittest import TestCase
import drivecasa
import os
import tempfile
import pexpect.exceptions
from drivecasa import default_test_ouput_dir


class TestDefaultCasaInterface(TestCase):
    """
    Ensure that the method of shelling out to CASA is working as expected.
    """
    def shortDescription(self):
        return None

    @classmethod
    def setUpClass(cls):
        cls.casa = drivecasa.Casapy(echo_to_stdout=False)

    def test_script_file(self):
        script = 'tasklist()\n'
        with tempfile.NamedTemporaryFile(delete=False) as tmpfile:
            tmpfile_path = tmpfile.name
            tmpfile.write(script)
        out, errors = self.casa.run_script_from_file(tmpfile_path)
#         for l in out:
#             print l
        self.assertNotEqual(len(out), 0)
        self.assertEqual(len(errors), 0)
        os.remove(tmpfile_path)

    def test_casa_command(self):
        script = ['tasklist()']
        out, errors = self.casa.run_script(script)
#         for l in out:
#             print l
        self.assertNotEqual(len(out), 0)
        self.assertEqual(len(errors), 0)

    def test_python_stdout_capture(self):
        script = ['print "Hello world"']
        out, errors = self.casa.run_script(script)
        # for l in out:
            # print l
        empty_output = True
        for l in out:
            if l:
                empty_output = False
                self.assertEqual(l, 'Hello world')
            # print "Output line:", l
        self.assertFalse(empty_output)
        self.assertEqual(len(errors), 0)

    @unittest.skip("Beware: result displays not captured, use 'print'.")
    def test_python_result_capture(self):
        script = ['2+2']
        out, errors = self.casa.run_script(script)
        empty_output = True
        for l in out:
            if l:
                empty_output = False
            # print "Output line:", l
        self.assertFalse(empty_output)
        self.assertEqual(len(errors), 0)

    def test_error_exception(self):
        script = ['importuvfits("dummy_in.fits", "dummy_out.ms")']
        with self.assertRaises(RuntimeError):
            out, errors = self.casa.run_script(script)

    def test_error_reporting(self):
        script = ['importuvfits("dummy_in.fits", "dummy_out.ms")']
        out, errors = self.casa.run_script(script, raise_on_severe=False)
        self.assertEqual(len(errors), 1)

    def test_timeout(self):
        script = ['import math',
                  'print math.pi',
                  ]
        self.casa.run_script(script)
        with self.assertRaises(pexpect.exceptions.TIMEOUT):
            self.casa.run_script(script, timeout=1e-5)



#         print "Errors:", errors
#     def test_logged_to_stdout_only(self):
#         stdout, stderr, errors = run_script(self.script, casa_dir=self.casa_dir,
#                    log2term=True,
#                    casa_logfile=False,
#                    return_stdout=True)
#         self.assertNotEqual(len(stdout), 0)
#         self.assertEqual(len(stderr), 0)
#         self.assertEqual(len(errors), 0)
#         print "Stdout:"
#         print stdout
#         print "Stderr:"
#         print stderr



# Import commonly-used data-reduction commands for convience
# (And backwards compatibility)
from drivecasa.commands.reduction import (
    clean,
    concat,
    export_fits,
    import_uvfits,
    mstransform
)


import unittest
from unittest import TestCase
import drivecasa
import os
import subprocess
import StringIO
import warnings
import shutil

from drivecasa import commands
from .. import sample_data as test_data


class TestImportUVFITS(TestCase):
    def shortDescription(self):
        return None

    @classmethod
    def setUpClass(cls):
        cls.casa = drivecasa.Casapy(echo_to_stdout=False)

    def setUp(self):
        self.output_dir = os.path.join(drivecasa.default_test_ouput_dir,
                                       'importuvfits_output')
        self.testfile = test_data.ami_uvfits_paths[0]
        # Ensure that the output dir will be created if not already present
        # (Also deletes the output ms if present)
        if os.path.isdir(self.output_dir):
            shutil.rmtree(self.output_dir)


    def test_default_and_overwrite_cases(self):
        script = []
        expected_ms = commands.import_uvfits(
                                    script,
                                    self.testfile,
                                    out_dir=self.output_dir)
        # Manually ensure target does not pre-exist
        if os.path.isdir(expected_ms):
             shutil.rmtree(expected_ms)
        # Test in usual case, not-preexisting
        self.casa.run_script(script)
        self.assertTrue(os.path.isdir(expected_ms))

        # Now it's there, check we overwrite OK (this is a no-brainer but still)
        script = []
        self.expected_ms = commands.import_uvfits(
                            script,
                            self.testfile,
                            out_dir=self.output_dir,
                             overwrite=True
                            )
        self.casa.run_script(script)

        # Now, attempt to run with overwriting turned off. This both ensures
        # we do not overwrite, and checks the error reporting mechanism:
        script = []
        self.expected_ms = commands.import_uvfits(
                            script,
                            self.testfile,
                            out_dir=self.output_dir,
                            # overwrite=False #(By default)
                            )
        with self.assertRaises(RuntimeError):
            self.casa.run_script(script)


    def test_specified_outpath(self):
        script = []
        expected_ms = commands.import_uvfits(
                                    script,
                                    self.testfile,
                                    out_dir=self.output_dir,
                                    out_path=self.output_dir + '/importuvfitsout.ms')
        # Manually ensure target does not pre-exist
        if os.path.isdir(expected_ms):
             shutil.rmtree(expected_ms)
        # Test in usual case, not-preexisting
        self.casa.run_script(script)
        self.assertTrue(os.path.isdir(expected_ms))

    def test_unicode_paths(self):
        script = []
        expected_ms = commands.import_uvfits(
            script,
            unicode(self.testfile),
            out_dir=unicode(self.output_dir),
            out_path=unicode(
                        os.path.join(self.output_dir, 'importuvfitsout.ms'))
        )

        # Manually ensure target does not pre-exist
        if os.path.isdir(expected_ms):
             shutil.rmtree(expected_ms)
        # Test in usual case, not-preexisting
        self.casa.run_script(script)
        self.assertTrue(os.path.isdir(expected_ms))



import unittest
from unittest import TestCase
import drivecasa
import os
import subprocess
import StringIO
import warnings
import shutil

from drivecasa import commands
from .. import sample_data as test_data


class TestClean(TestCase):
    def shortDescription(self):
        return None

    @classmethod
    def setUpClass(cls):
        cls.casa = drivecasa.Casapy(echo_to_stdout=False)

    def setUp(self):
        self.output_dir = os.path.join(drivecasa.default_test_ouput_dir,
                                       'clean_output')
        self.testvis_single = test_data.ami_vis_paths[0]
        self.testvis_multiple = test_data.ami_vis_paths
        # Ensure that the output dir will be created if not already present
        # (Also deletes the output ms if present)
        if os.path.isdir(self.output_dir):
            shutil.rmtree(self.output_dir)
        self.clean_args = {"spw": '0:0~5',
                           "imsize": [512, 512],
                           "cell": ['5.0arcsec'],
                           "pbcor": False,
                           #           "weighting": 'natural',
                           "weighting": 'briggs',
                           "robust": 0.5,
                           #          "weighting":'uniform',
                           "psfmode": 'clark',
                           "imagermode": 'csclean',
                           }

    def test_dirty_map(self):
        script = []
        expected_maps = commands.clean(script,
                                       vis_paths=self.testvis_single,
                                       out_dir=self.output_dir+'/dirty_map',
                                       niter=0,
                                       threshold_in_jy=1,
                                       mask='',
                                       other_clean_args=self.clean_args,
                                       overwrite=True)

        print expected_maps
        # Manually ensure target does not pre-exist
        for map in expected_maps:
            if os.path.isdir(map):
                shutil.rmtree(map)
        # Test in usual case, not-preexisting
        casa_out, errs = self.casa.run_script(script)
        #         print '\n'.join(casa_out)
        self.assertTrue(os.path.isdir(expected_maps.image))

    def test_clean_map(self):
        script = []
        expected_maps = commands.clean(script,
                                       vis_paths=self.testvis_single,
                                       out_dir=self.output_dir+'/clean_map',
                                       niter=500,
                                       threshold_in_jy=0.2 / 1000.,
                                       mask='',
                                       other_clean_args=self.clean_args,
                                       overwrite=True)

        print expected_maps
        # Manually ensure target does not pre-exist
        for map in expected_maps:
            if os.path.isdir(map):
                shutil.rmtree(map)
        # Test in usual case, not-preexisting
        casa_out, errs = self.casa.run_script(script)
        print '\n'.join(casa_out)
        self.assertTrue(os.path.isdir(expected_maps.image))

    def test_multivis_clean_map(self):
        script = []
        expected_maps = commands.clean(script,
                                       vis_paths=self.testvis_multiple,
                                       out_dir=self.output_dir+'/mvclean_map',
                                       niter=500,
                                       threshold_in_jy=0.2 / 1000.,
                                       mask='',
                                       other_clean_args=self.clean_args,
                                       overwrite=True)

        print expected_maps
        # Manually ensure target does not pre-exist
        for map in expected_maps:
            if os.path.isdir(map):
                shutil.rmtree(map)
        # Test in usual case, not-preexisting
        casa_out, errs = self.casa.run_script(script)
        print '\n'.join(casa_out)
        self.assertTrue(os.path.isdir(expected_maps.image))

    # def




"""
Drive-casa is an interfacing package for scripting of CASA from a separate
Python process (see :ref:`introduction`).

The package includes several convenience routines that allow chaining of CASA
commands, see :py:mod:`.commands` module.
"""

from __future__ import absolute_import
import os
import sys

from pkg_resources import get_distribution, DistributionNotFound

import drivecasa.commands
import drivecasa.utils
from drivecasa.casa_env import casapy_env
from drivecasa.interface import Casapy


default_test_ouput_dir = '/tmp/drivecasa-tests'


from ._version import get_versions
__version__ = get_versions()['version']
del get_versions



#!/usr/bin/env python

from setuptools import setup, find_packages
import versioneer

install_requires = [
        'astropy',
        'pexpect>4'
    ]

setup(
    name="drive-casa",
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    packages=find_packages(),
    description="An interfacing package for scripting CASA from an "
                "external pipeline.",
    author="Tim Staley",
    author_email="github@timstaley.co.uk",
    url="https://github.com/timstaley/drive-casa",
    license='BSD 3-clause',
    install_requires=install_requires,
)



from unittest import TestCase
import drivecasa
import os
import subprocess
import warnings

from drivecasa.interface import default_casa_dir

class TestCasaInstallation(TestCase):
    """Ensures that casapy is available, either through the pre-existing
    environment path, or via the casapy dir specified to the casapy_env
    function."""
    def shortDescription(self):
        return None
    def setUp(self):
        self.env = drivecasa.casapy_env(default_casa_dir)
        self.known_good_casa_versions = ['4.1.0 (r24668)',
                                         '4.2.1 (r29048)',
                                         '4.2.2 (r30986)',
                                         '4.3.0-REL (r31966)',
                                         '4.4.0-REL (r33623)',
                                         '4.5.2-REL (r36115)',
                                         ]

    def test_casa_version(self):
        cmd = ['casa', '--help']

        output = subprocess.check_output(cmd,
                              env=self.env
                              )
        version = None
        for line in output.split('\n'):
            if 'Version' in line:
                version = line[len('CASA Version '):]
        print "Version:", version
        self.assertNotEqual(None, version)
        if version not in self.known_good_casa_versions:
            warnings.warn("This library has not been tested against CASA version " +
                          version + ", known good versions are:\n"
                          + str(self.known_good_casa_versions)
                          )



import unittest
from unittest import TestCase
import drivecasa
import os
import tempfile
from drivecasa import default_test_ouput_dir


class TestCommandLogging(TestCase):
    """
    Ensure that logging of commands works correctly.
    """
    def shortDescription(self):
        return None

    def test_command_logging(self):
        with tempfile.NamedTemporaryFile(delete=False) as tmpfile:
            commands_logfile = tmpfile.name
            #Use the temporary file path, but delete the empty file first...
            os.remove(commands_logfile)
        casa = drivecasa.Casapy(commands_logfile=commands_logfile,
                                    echo_to_stdout=False)
        script = ['tasklist()']
        out, errors = casa.run_script(script)
        with open(commands_logfile) as f:
            commands_log = f.read()

        commands_logged = commands_log.split('\n')
        if not commands_logged[-1]:
            commands_logged.pop()
        self.assertEqual(commands_logged, script)
        # print "Command log", commands_log
        os.remove(commands_logfile)
